#define DEBUG 1
#define VERSION "3.12.3"
#define ADATE   "26 April 2006"

#define APCUPSD_RELEASE VERSION

#ifndef APCUPSD_HOST
# define APCUPSD_HOST HOST
#endif
